> Thank you for submitting a change to this project!
>
> If you haven't done so yet, we suggest you read the (see docs/CONTRIBUTOR AGREEMENT.md). This is a legal document that details the legal rights and obligations of both Pasqal and you regarding your submission. Whenever you submit code, you accept this contributor licence agreement.
>
> If you wish to discuss with the developers and contributors, don't hesitate to join [the Pasqal Community Slack](https://pasqal-community.slack.com/join/shared_invite/zt-2y7drym29-ZEH_uZlasEUDhrG9Tk0Vuw#/shared-invite/email)! It's a good place to chat about quantum computing and discuss project ideas.
